@@ -105,15 +105,3 @@ def fb_match_defensive_actions_stats(pageSoup=None, url: str = None):
             defensive_stats_y = mylist.copy()
 
     return defensive_stats_x, defensive_stats_y
-
-
-if __name__ == "__main__":
-    url = "/en/matches/c2e426c8/Leicester-City-Watford-November-28-2021-Premier-League"
-    page = "https://fbref.com" + url
-    # from util_placeholder import get_page_soup
-
-    # pageSoup = get_page_soup(page)
-    # stats_x, stats_y = fb_match_defensive_actions_stats(pageSoup)
-
-    stats_x, stats_y = fb_match_defensive_actions_stats(url=page)
-    print(stats_x)
