@@ -1,7 +1,7 @@
 from ..util import get_page_soup
 
 
-def fb_match_metadata(pageSoup=None, url: str = None):
+def fb_match_metadata(pageSoup=None, url: str = None, verbose: bool = False):
     """Extracts general information (teams, managers, captains, date, time, venue, attendance, score, xG) for a given match
 
     Args:
@@ -24,6 +24,7 @@ def fb_match_metadata(pageSoup=None, url: str = None):
     # Extract url
     url = pageSoup.find("meta", {"property": "og:url"})["content"]
     url = url.replace("https://fbref.com", "")
+    match_id = url.split("/")[3]
 
     # Find scorebox object
     scorebox = pageSoup.find("div", {"class": "scorebox"})
@@ -31,10 +32,16 @@ def fb_match_metadata(pageSoup=None, url: str = None):
     teams = scorebox.find_all("strong")
 
     # extract team id and name
-    id_x = teams[0].find("a", href=True)["href"].split("/")[3]
-    id_y = teams[3].find("a", href=True)["href"].split("/")[3]
-    team_x = teams[0].find("a", href=True).text
-    team_y = teams[3].find("a", href=True).text
+    if len(teams) == 7:
+        id_x = teams[0].find("a", href=True)["href"].split("/")[3]
+        id_y = teams[2].find("a", href=True)["href"].split("/")[3]
+        team_x = teams[0].find("a", href=True).text
+        team_y = teams[2].find("a", href=True).text
+    else:
+        id_x = teams[0].find("a", href=True)["href"].split("/")[3]
+        id_y = teams[3].find("a", href=True)["href"].split("/")[3]
+        team_x = teams[0].find("a", href=True).text
+        team_y = teams[3].find("a", href=True).text
 
     # extract scores
     scores = pageSoup.find_all("div", {"class": "scores"})
@@ -51,12 +58,38 @@ def fb_match_metadata(pageSoup=None, url: str = None):
     except AttributeError:
         xg_y = None
 
+    if verbose:
+        if "*" in score_x:
+            print(
+                f"{match_id} match between {team_x} and {team_y} was forfeited and awarded to {team_x}"
+            )
+            score_x = score_x.replace("*", "")
+        elif "*" in score_y:
+            print(
+                f"{match_id} match between {team_x} and {team_y} was forfeited and awarded to {team_y}"
+            )
+            score_y = score_y.replace("*", "")
+
     # extract managers and captains
     managers = pageSoup.find_all("div", {"class": "datapoint"})
-    manager_x = managers[0].text.replace("Manager: ", "")
-    manager_y = managers[2].text.replace("Manager: ", "")
-    captain_x = managers[1].find("a", href=True)["href"]
-    captain_y = managers[3].find("a", href=True)["href"]
+    if len(managers) == 4:
+        manager_x = managers[0].text.replace("Manager: ", "")
+        manager_y = managers[2].text.replace("Manager: ", "")
+        captain_x = managers[1].find("a", href=True)["href"]
+        captain_y = managers[3].find("a", href=True)["href"]
+        captain_id_x = captain_x.split("/")[3]
+        captain_id_y = captain_y.split("/")[3]
+    else:
+        manager_x = None
+        manager_y = None
+        captain_x = None
+        captain_y = None
+        captain_id_x = None
+        captain_id_y = None
+        if verbose:
+            print(
+                f"{match_id} match between {team_x} and {team_y} missing manager or captain"
+            )
 
     # Find match information object
     scorebox_meta = pageSoup.find("div", {"class": "scorebox_meta"})
@@ -68,6 +101,8 @@ def fb_match_metadata(pageSoup=None, url: str = None):
 
     # extract attendance, venue, and official information
     scorebox_meta_ = scorebox_meta.find_all("div")
+    if "*Match awarded to " in scorebox_meta_[3].text:
+        scorebox_meta_.pop(3)
     if scorebox_meta_[4].text.startswith("Attendance:"):
         attendance = scorebox_meta_[4].text
         attendance = attendance.replace("Attendance: ", "")
@@ -80,9 +115,9 @@ def fb_match_metadata(pageSoup=None, url: str = None):
         officials = scorebox_meta_[5].find_all("small")[1].text.split("\xa0· ")
 
     # generate dictionary for general metadata
-    matadict = {
+    metadict = {
         "url": url,
-        "match_id": url.split("/")[3],
+        "match_id": match_id,
         "id_x": id_x,
         "id_y": id_y,
         "team_x": team_x,
@@ -94,9 +129,9 @@ def fb_match_metadata(pageSoup=None, url: str = None):
         "manager_x": manager_x,
         "manager_y": manager_y,
         "captain_x": captain_x,
-        "captain_id_x": captain_x.split("/")[3],
+        "captain_id_x": captain_id_x,
         "captain_y": captain_y,
-        "captain_id_y": captain_y.split("/")[3],
+        "captain_id_y": captain_id_y,
         "date": date,
         "kickoff": kickoff,
         "attendance": attendance,
@@ -119,4 +154,4 @@ def fb_match_metadata(pageSoup=None, url: str = None):
         "var": var,
     }
 
-    return matadict, officialsdict
+    return metadict, officialsdict
